@@ -29,7 +29,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: kernel.c,v 1.5 1998/03/04 11:43:32 provos Exp $";
+static char rcsid[] = "$Id: kernel.c,v 1.7 1998/03/16 20:49:50 provos Exp $";
 #endif
 
 #ifdef linux
@@ -173,6 +173,25 @@ kernel_get_socket(void)
      return sd;
 }
 
+void
+kernel_set_socket_policy(int sd)
+{
+     u_char level;
+
+     /*
+      * Need to bypass system security policy, so I can send and
+      * receive key management datagrams in the clear.
+      */
+
+     level = IPSEC_LEVEL_NONE;   /* Did I mention I'm privileged? */
+     if (setsockopt(sd, IPPROTO_IP, SO_SECURITY_AUTHENTICATION, (char *)&level,
+		    sizeof (u_char)) == -1)
+	  crit_error(1, "setsockopt: can not bypass ipsec authentication policy");
+     if (setsockopt(sd, IPPROTO_IP, SO_SECURITY_ENCRYPTION_TRANSPORT,
+			(char *)&level, sizeof (u_char)) == -1)
+	  crit_error(1, "setsockopt: can not bypass ipsec esp transport policy");
+}
+
 int
 kernel_xf_set(struct encap_msghdr *em)
 {
